package it.unimi.dsi.mg4j.index;

import it.unimi.dsi.mg4j.util.MutableString;

/*		 
 * MG4J: Managing Gigabytes for Java
 *
 * Copyright (C) 2004 Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


/** A map from term to term indices.
 *
 * <P>To build document iterators at the base of a compound query,
 * a parser need to know, given a term as a character sequence,
 * which is the corresponding inverted list of the index. A class
 * implementing this interface may be used to this purpose.
 * 
 * <P>A term map must return, given a character sequence, a natural
 * number. Optionally, it may return -1 if the character sequence was not indexed.
 * The latter behaviour is <em>not</em> enforced, so that, for example, {@link it.unimi.dsi.mg4j.util.MinimalPerfectHash}
 * instances may be used when it is known <i>a priori</i> whether a term has been indexed or not.
 *
 * <P>Optionally, an instance of this class may provide two-way access
 * to terms.
 *
 * @author Sebastiano Vigna 
 * @since 0.9
 */

public interface TermMap {
	/** Returns the index corresponding to the given term, or possibly (but not necessarily) -1 if the term was not indexed.
	 * 
	 * @param term a term.
	 * @return its ordinal number, or possibly (but not necessarily) -1 if the term was not indexed.
	 */

	public int get( CharSequence term );

	/** Returns the term corresponding to the given index (optional operation).
	 * 
	 * @param index a term index.
	 * @return the corresponding term, or possibly (but not necessarily) <code>null</code> if the term was not indexed.
	 */

	public CharSequence get( int index );

	/** Writes in the given mutable string the term corresponding to the given index (optional operation).
	 * 
	 * @param index a term index.
	 * @param term a mutable string that will be fillted with the corresponding term.
	 * @return <code>term</code>, or possibly (but not necessarily) <code>null</code> if the term was not indexed.
	 */

	public MutableString get( int index, MutableString term );
}
