package it.unimi.dsi.mg4j.search;

import java.util.Iterator;

/*		 
 * MG4J: Managing Gigabytes for Java
 *
 * Copyright (C) 2003, 2004 Paolo Boldi and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

                                                                                                                                                           
                                                                                                                                                             
/** An interface that allows one to iterate over {@linkplain Interval intervals}.
 *  Apart for the usual methods of a (type-specific) iterator, it
 *  has a special (optional) {@link #reset()} method that allows one to reset
 *  the iterator: the exact meaning of this operation is decided by the
 *  implementing classes. Typically, after a {@link #reset()}, one can
 *  iterate over a new sequence.
 *
 *  <P>This interface also specifies a method {@link #extent()} returning
 *  a positive integer that is supposed to approximate the minimum possible
 *  length of an interval returned by this iterator. This method returns -1
 *  if this extent cannot be computed.
 */
public interface IntervalIterator extends Iterator {

	/** Returns the next interval in the sequence.
	 *
	 * <P>A call to this method is equivalent to {@link Iterator#next() (Interval)next()}.
	 *  
	 * @throws UnsupportedOperationException if this iterator has multiple indices.
	 * @return the next interval in the sequence. 
	 */
	public Interval nextInterval();

	/** Resets the internal state of this iterator for a new document. 
	 *
	 * <P>To reduce object creation, interval iterators are usually created in a lazy
	 * fashion by document iterator when they are needed. However, this implies that
	 * every time the document iterator is moved, some internal state of the interval iterator must be reset
	 * (e.g., because on the new document some of the component interval iterators are now
	 * {@link IntervalIterators#TRUE}).
	 */
	public void reset();       
	
	/** Returns an approximation of a lower bound for the length of an interval
	 *  returned by this iterator.
 	 *
	 *  @return an approximation of a lower bound for the length of an interval.
	 */
	public int extent();
	
	
}
                                                                                                                                                        
// Local Variables:
// mode: jde
// tab-width: 4
// End:
