package it.unimi.dsi.mg4j.search;

import java.util.Comparator;

/*		 
 * MG4J: Managing Gigabytes for Java
 *
 * Copyright (C) 2003, 2004 Paolo Boldi and Sebastiano Vigna 
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

                                                                                                                                                             
/** A class providing static methods and objects that do useful things with intervals. */

public class Intervals {

	private Intervals() {}

	public final static Interval[] EMPTY_ARRAY = {};

	/** A comparator between intervals, defined as follows: an interval
	 *  [<var>a</var>, <var>b</var>] is less than [<var>a</var>', <var>b</var>'] 
	 * iff <var>a</var> &lt; <var>a</var>' or <var>a</var>=<var>a</var>' and <var>b</var> &gt; <var>b</var>'.
	 */
	public final static Comparator LEFT_INTERVAL_COMPARATOR = new Comparator() {
		public int compare( Object o1, Object o2 ) {
			Interval i1 = (Interval) o1;
			Interval i2 = (Interval) o2;
			if ( i1.left != i2.left ) return i1.left - i2.left;
			return i2.right - i1.right;
		}
	};

	/** A comparator between intervals, defined as follows: an interval
	 * [<var>a</var>, <var>b</var>] is less than [<var>a</var>', <var>b</var>'] 
	 * if <var>b</var> &gt; <var>b</var>'; otherwise,
	 * [<var>a</var>, <var>b</var>] is greater than [<var>a</var>', <var>b</var>'], unless they are equal.
	 */
	public final static Comparator RIGHT_INTERVAL_COMPARATOR = new Comparator() {
		public int compare( Object o1, Object o2 ) {
			Interval i1 = (Interval) o1;
			Interval i2 = (Interval) o2;
			if ( i1.right != i2.right ) return i2.right - i1.right;
			if ( i1.left != i2.left ) return 1;
			return 0;
		}
	};                                                                                                                    


                                                                                                                                                            
}
                                                                                                                                                        

// Local Variables:
// mode: jde
// tab-width: 4
// End:
