package it.unimi.dsi.mg4j.search.score;

/*		 
 * MG4J: Managing Gigabytes for Java
 *
 * Copyright (C) 2004 Paolo Boldi
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITfNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

import it.unimi.dsi.mg4j.search.DocumentIterator;
import it.unimi.dsi.mg4j.index.Index;

/** A {@linkplain it.unimi.dsi.mg4j.search.DocumentIterator document iterator}
 * with additional methods that return the score of the current
 * document, either with respect to a specified index ({@link #score(Index)}),
 * or globally ({@link #score()}).
 * 
 * <P>Note that the score methods must be called just after 
 * the {@link #nextDocument()} method, and calling one of those
 * method may inhibit calls to {@link #intervalIterator(Index)}
 * and such (this is implementation dependent, though).
 */
public interface ScoredDocumentIterator extends DocumentIterator {

	/** Returns the score of the current document with respect to
	 *  the given index.
	 * 
	 * @return the score of the current document.
	 */
	public double score( Index index );
	
	/** Returns the overall score of the current document.
	 * 
	 * @return the score of the current document.
	 */
	public double score();

}
